==> very-express-ionic-vue-0.0.2.tgz: package/src/generators/vuelidate_jsonSchema.ts <==
// import { useVuelidate } from '@vuelidate/core';
import fs from "fs";
import util from "util";
import log from "../utils/logger";
import { indexTemplate, vexlidateTemplate } from "../templates/vexlidate.template";

export function generate(jsonSchema: any, outFile: string): void {
    log.process("vuelidate", jsonSchema?.["x-documentConfig"]?.interfaceName);

    const validatorsTemplateRaw = util.inspect(schemaToVuelidate(jsonSchema));
    const validatorsTemplate = validatorsTemplateRaw.replace(/'{{/g, "").replace(/}}'/g, "");

    const contentTemplate = `import * as validators from '@vuelidate/validators';
export default ${validatorsTemplate}`;

    log.writing("vuelidate", outFile);
    return fs.writeFileSync(outFile, contentTemplate);
}

export function makeFile(outDir: string): void {
    const utilsFile = `${outDir}/utils.ts`;
    if ( !fs.existsSync(utilsFile) ) {
        fs.writeFileSync(utilsFile, vexlidateTemplate());
    };

    const indexFile = `${outDir}/index.ts`;
    if ( !fs.existsSync(indexFile) ) {
        fs.writeFileSync(indexFile, indexTemplate());
    };
}

// Function to convert JSON schema to Vuelidate rules
export function schemaToVuelidate(schema: { [key: string]: any }) {
    
    const validatorConfigs: { [key: string]: any } = {};
    const ObjectKeys = Object.keys(schema?.properties);

    ObjectKeys.forEach((key) => {
        const value = schema.properties[key];
        validatorConfigs[key] = schemaItemToVuelidate(schema, key, value);
    });

    return validatorConfigs;
}

export function schemaItemToVuelidate(schema: any, key: string, value: { [key: string]: any }) {

    let validationConfig: any = {};

    if (schema.required && schema.required.includes(key)) {
        validationConfig.required = `{{validators.required}}`;
    }

    // type specific validations
    switch (value.type) {
        case 'string':
            if (value.format === 'email') {
                validationConfig.email = `{{validators.email}}`;
            }
            if (value.minLength) {
                validationConfig.minLength = `{{validators.minLength(${value.minLength})}}`;
            }
            if (value.maxLength) {
                validationConfig.maxLength = `{{validators.maxLength(${value.maxLength})}}`;
            }
            if (value.pattern === '^[a-zA-Z0-9]*$') {
                validationConfig.alphaNum = `{{validators.alphaNum}}`;
            }
            break;
        case 'number':
            validationConfig.numeric = `{{validators.numeric}}`;
            if (value.minValue && value.maxValue) {
                validationConfig.between = `{{validators.between(${value.minValue}, ${value.maxValue})}}`;
            }
            else if (value.minValue !== undefined) {
                validationConfig.minValue = `{{validators.minValue(${value.minValue})}}`;
            }
            else if (value.maxValue !== undefined) {
                validationConfig.maxValue = `{{validators.maxValue(${value.maxValue})}}`;
            }
            break;
        case 'object':
            // loop through the object properties
            const objectValidations = schemaToVuelidate(value);
            validationConfig = objectValidations;
            break;
        case 'array':
            // loop through the array items
            const arrayValidations = schemaItemToVuelidate(schema, key, value.items);
            validationConfig = arrayValidations;
            break;
        case 'boolean':
            // Vuelidate doesn't have a specific boolean validator
            break;
        default:
            break;
    }

    // format specific validations
    if (value.format) {
        switch (value.format) {
            case 'email':
            case 'emailAddress':
                validationConfig.email = `{{validators.email}}`;
                break;
            case 'uri':
            case 'url':
                validationConfig.url = `{{validators.url}}`;
                break;
            case 'ipv4':
            case 'ipv6':
            case 'ipAddress':
                validationConfig.ipAddress = `{{validators.ipAddress}}`;
                break;
            case 'mac':
            case 'macAddress':
                validationConfig.macAddress = `{{validators.macAddress}}`;
                break;
            default:
                break;
        }
    };

    // oneOf specific validations
    if (value.oneOf) {
        const oneOf = value.oneOf.map((item: any) => schemaItemToVuelidate(schema, key, item));
        validationConfig.oneOf = `{{validators.or(${oneOf})}}`;
    }

    return validationConfig;
};

export default {
    generate,
    makeFile,
    schemaToVuelidate,
    schemaItemToVuelidate
};

==> very-express-ionic-vue-0.0.6.tgz: package/src/generators/vuelidate_jsonSchema.ts <==
// import { useVuelidate } from '@vuelidate/core';
import fs from "fs";
import util from "util";
import log from "../utils/logger";
import { indexTemplate, vexlidateTemplate } from "../templates/vexlidate.template";

export function generate(jsonSchema: any, outFile: string): void {
    log.process("vuelidate", jsonSchema?.["x-documentConfig"]?.documentName);

    const validatorsTemplateRaw = util.inspect(schemaToVuelidate(jsonSchema));
    const validatorsTemplate = validatorsTemplateRaw.replace(/'{{/g, "").replace(/}}'/g, "");

    const contentTemplate = `import * as validators from '@vuelidate/validators';
export default ${validatorsTemplate}`;

    log.writing("vuelidate", outFile);
    return fs.writeFileSync(outFile, contentTemplate);
}

export function makeFile(outDir: string): void {
    const utilsFile = `${outDir}/utils.ts`;
    if ( !fs.existsSync(utilsFile) ) {
        fs.writeFileSync(utilsFile, vexlidateTemplate());
    };

    const indexFile = `${outDir}/index.ts`;
    if ( !fs.existsSync(indexFile) ) {
        fs.writeFileSync(indexFile, indexTemplate());
    };
}

// Function to convert JSON schema to Vuelidate rules
export function schemaToVuelidate(schema: { [key: string]: any }) {
    
    const validatorConfigs: { [key: string]: any } = {};
    const ObjectKeys = Object.keys(schema?.properties);

    ObjectKeys.forEach((key) => {
        const value = schema.properties[key];
        validatorConfigs[key] = schemaItemToVuelidate(schema, key, value);
    });

    return validatorConfigs;
}

export function schemaItemToVuelidate(schema: any, key: string, value: { [key: string]: any }) {

    let validationConfig: any = {};

    if (schema.required && schema.required.includes(key)) {
        validationConfig.required = `{{validators.required}}`;
    }

    // type specific validations
    switch (value.type) {
        case 'string':
            if (value.format === 'email') {
                validationConfig.email = `{{validators.email}}`;
            }
            if (value.minLength) {
                validationConfig.minLength = `{{validators.minLength(${value.minLength})}}`;
            }
            if (value.maxLength) {
                validationConfig.maxLength = `{{validators.maxLength(${value.maxLength})}}`;
            }
            if (value.pattern === '^[a-zA-Z0-9]*$') {
                validationConfig.alphaNum = `{{validators.alphaNum}}`;
            }
            break;
        case 'number':
            validationConfig.numeric = `{{validators.numeric}}`;
            if (value.minValue && value.maxValue) {
                validationConfig.between = `{{validators.between(${value.minValue}, ${value.maxValue})}}`;
            }
            else if (value.minValue !== undefined) {
                validationConfig.minValue = `{{validators.minValue(${value.minValue})}}`;
            }
            else if (value.maxValue !== undefined) {
                validationConfig.maxValue = `{{validators.maxValue(${value.maxValue})}}`;
            }
            break;
        case 'object':
            // loop through the object properties
            const objectValidations = schemaToVuelidate(value);
            validationConfig = objectValidations;
            break;
        case 'array':
            // loop through the array items
            const arrayValidations = schemaItemToVuelidate(schema, key, value.items);
            validationConfig = arrayValidations;
            break;
        case 'boolean':
            // Vuelidate doesn't have a specific boolean validator
            break;
        default:
            break;
    }

    // format specific validations
    if (value.format) {
        switch (value.format) {
            case 'email':
            case 'emailAddress':
                validationConfig.email = `{{validators.email}}`;
                break;
            case 'uri':
            case 'url':
                validationConfig.url = `{{validators.url}}`;
                break;
            case 'ipv4':
            case 'ipv6':
            case 'ipAddress':
                validationConfig.ipAddress = `{{validators.ipAddress}}`;
                break;
            case 'mac':
            case 'macAddress':
                validationConfig.macAddress = `{{validators.macAddress}}`;
                break;
            default:
                break;
        }
    };

    // oneOf specific validations
    if (value.oneOf) {
        const oneOf = value.oneOf.map((item: any) => schemaItemToVuelidate(schema, key, item));
        validationConfig.oneOf = `{{validators.or(${oneOf})}}`;
    }

    return validationConfig;
};

export default {
    generate,
    makeFile,
    schemaToVuelidate,
    schemaItemToVuelidate
};
